@@ -1,4 +1,4 @@
-/* $Id: substr.cc 860 2008-04-09 22:57:45Z nuno-lopes $ */
+/* $Id$ */
 #include <string.h>
 #include <stdlib.h>
 #include "substr.h"
@@ -36,13 +36,6 @@ Str::Str(const SubStr& s)
 	;
 }
 
-Str::Str(Str& s)
-	: SubStr(s.str, s.len)
-{
-	s.str = NULL;
-	s.len = 0;
-}
-
 Str::Str(const char *s)
 	: SubStr(strdup(s), strlen(s))
 {
